@@ -1,10 +1,10 @@
 import asyncio
-from tomoe.pururin import get_pur
-from tomoe.nhentai import get_nh
-from tomoe.simplyh import get_sim
-from tomoe.hentaifox import get_hfox
-from tomoe.hentai2read import get_h2r
-from tomoe.utils.misc import choose
+from tomoe.tomoe.pururin import get_pur
+from tomoe.tomoe.nhentai import get_nh
+from tomoe.tomoe.simplyh import get_sim
+from tomoe.tomoe.hentaifox import get_hfox
+from tomoe.tomoe.hentai2read import get_h2r
+from tomoe.tomoe.utils.misc import choose
 
 
 class Tomoe():
